@@ -1,7 +1,7 @@
 /* rand_funcs.c:  General purpose random number functions.
 
-   Copyright (C) 2021 by Brian Lindholm.  This file is part of the littleutils
-   utility set.
+   Copyright (C) 2021-2026 by Brian Lindholm.  This file is part of the
+   littleutils utility set.
 
    The rand_funcs.c file is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
    You should have received a copy of the GNU General Public License along with
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
-
 #include <config.h>
 
 #include <fcntl.h>
@@ -42,7 +41,7 @@ unsigned short _djstat_flags = 63;
 #include "rand_funcs.h"
 
 /* initialize random number generator seed */
-void rand_seed ()
+void rand_seed()
 {
   int urandom_worked = 1;
   ssize_t bytes;
@@ -55,21 +54,16 @@ void rand_seed ()
 
   /* pre-populate array for seed using /dev/urandom */
 #ifdef HAVE_GETRANDOM
-  bytes = getrandom(seed, sizeof seed, GRND_NONBLOCK);
-  if (bytes < 6) {
-    urandom_worked = 0;
-  }
+  bytes = getrandom(seed, sizeof(seed), GRND_NONBLOCK);
+  if (bytes < 6) urandom_worked = 0;
 #else
   int URANDOM = open("/dev/urandom", O_RDONLY);
-  if (URANDOM < 0) {
+  if (URANDOM < 0)
     urandom_worked = 0;
-  }
   else {
     /* use read instead of buffered fread to avoid grabbing extra bytes */
-    bytes = read(URANDOM, seed, sizeof seed);
-    if (bytes < 6) {
-      urandom_worked = 0;
-    }
+    bytes = read(URANDOM, seed, sizeof(seed));
+    if (bytes < 6) urandom_worked = 0;
   }
   close(URANDOM);
 #endif
@@ -80,39 +74,38 @@ void rand_seed ()
     (void) clock_getres(CLOCK_MONOTONIC, &res);
     (void) clock_gettime(CLOCK_MONOTONIC, &junk);
     seed[0] = (unsigned short) ((junk.tv_nsec / res.tv_nsec) & 0xFFFF);
-    seed[1] = (unsigned short) (getpid () & 0xFFFF);
+    seed[1] = (unsigned short) (getpid() & 0xFFFF);
     seed[2] = (unsigned short) (junk.tv_sec & 0xFFFF);
 #else
-    (void) time (&junk);
+    (void) time(&junk);
     seed[0] = (unsigned short) (junk & 0xFFFF);
-    seed[1] = (unsigned short) (getpid () & 0xFFFF);
+    seed[1] = (unsigned short) (getpid() & 0xFFFF);
     seed[2] = (unsigned short) ((junk >> 16) & 0xFFFF);
 #endif
   }
 
   /* initialize random number generator seed */
 #ifdef HAVE_LRAND48
-  (void) seed48 (seed);
+  (void) seed48(seed);
 #elif defined(HAVE_RANDOM)
-  srandom (((unsigned int) seed[0] << 16) + (unsigned int) seed[1]);
+  srandom(((unsigned int) seed[0] << 16) + (unsigned int) seed[1]);
 #else
-  srand (((unsigned int) seed[0] << 16) + (unsigned int) seed[1]);
+  srand(((unsigned int) seed[0] << 16) + (unsigned int) seed[1]);
 #endif
 }
 
 /* generate a random integer between 0 and n-1 */
-size_t rand_int (size_t n)
+size_t rand_int(size_t n)
 {
   size_t x;
 
 #if defined(HAVE_LRAND48)
-  x = (size_t) ((double) n * drand48 ());
+  x = (size_t) ((double) n * drand48());
 #elif defined(HAVE_RANDOM)
-  x = (size_t) ((double) n * ((double) random () / (double) 2147483648.0));
+  x = (size_t) ((double) n * ((double) random() / (double) 2147483648.0));
 #else
-  x = (size_t) ((double) n * ((double) rand () / ((double) RAND_MAX + 1.0)));
+  x = (size_t) ((double) n * ((double) rand() / ((double) RAND_MAX + 1.0)));
 #endif
-  if (x > (n - 1))
-    x = 0;
-  return (x);
+  if (x > (n - 1)) x = 0;
+  return(x);
 }
